@@ -676,13 +676,16 @@ def cli(
                                                     user_id = await client.get_entity(
                                                         PeerUser(int(user_id))
                                                     )
-                                                    user_id = str(user_id)
-                                                    result = (
-                                                        "User: "
-                                                        + str(ent.first_name)
-                                                        + " / ID: "
-                                                        + str(user_id.id)
-                                                    )
+                                                    if chat_type != "Channel":
+                                                        user_id = str(user_id)
+                                                        result = (
+                                                            "User: "
+                                                            + str(ent.first_name)
+                                                            + " / ID: "
+                                                            + str(user_id.id)
+                                                        )
+                                                    else:
+                                                        result = str(ent.title)
                                                 else:
                                                     result = str(ent.title)
 
@@ -1060,7 +1063,7 @@ def cli(
                                                 else:
                                                     has_media = 'FALSE'
 
-                                                post_url = "https://t.me/s/" + t + "/" + message.id
+                                                post_url = "https://t.me/s/" + t + "/" + str(message.id)
 
                                                 message_list.append(
                                                     [
